@@ -194,6 +194,7 @@ static TranslationEntry translations [] = {
         { "org.gnome.desktop.interface", "can-change-accels",      "Gtk/CanChangeAccels",     translate_bool_int },
         { "org.gnome.desktop.interface", "cursor-blink",           "Net/CursorBlink",         translate_bool_int },
         { "org.gnome.desktop.interface", "cursor-blink-time",      "Net/CursorBlinkTime",     translate_int_int },
+        { "org.gnome.desktop.interface", "cursor-blink-timeout",   "Gtk/CursorBlinkTimeout",  translate_int_int },
         { "org.gnome.desktop.interface", "gtk-theme",              "Net/ThemeName",           translate_string_string },
         { "org.gnome.desktop.interface", "gtk-timeout-initial",    "Gtk/TimeoutInitial",      translate_int_int },
         { "org.gnome.desktop.interface", "gtk-timeout-repeat",     "Gtk/TimeoutRepeat",       translate_int_int },
@@ -611,7 +612,7 @@ terminate_cb (void *data)
         }
 
         *terminated = TRUE;
-
+        g_warning ("X Settings Manager is terminating");
         gtk_main_quit ();
 }
 
@@ -750,14 +751,22 @@ gnome_xsettings_manager_stop (GnomeXSettingsManager *manager)
                 p->managers = NULL;
         }
 
-        g_object_unref (manager->priv->plugin_settings);
+        if (p->plugin_settings != NULL) {
+                g_object_unref (p->plugin_settings);
+                p->plugin_settings = NULL;
+        }
+
         stop_fontconfig_monitor (manager);
 
-        g_hash_table_destroy (p->settings);
-        p->settings = NULL;
+        if (p->settings != NULL) {
+                g_hash_table_destroy (p->settings);
+                p->settings = NULL;
+        }
 
-        g_object_unref (p->gtk);
-        p->gtk = NULL;
+        if (p->gtk != NULL) {
+                g_object_unref (p->gtk);
+                p->gtk = NULL;
+        }
 }
 
 static void
